@@ -5,8 +5,7 @@ from .delayed import Delayed
 from .dataset import Dataset
 from .dataset_factory import DatasetFactory
 from .repo_data import RepoData
-from .simple_task import SimpleTask
-from .source import Source
+from .job import Job
 from .task import Task
 from .repr import Repr
 from .logger import Logger
