@@ -6,7 +6,7 @@ from hypergol.name_string import NameString
 from hypergol.hypergol_project import HypergolProject
 
 
-def create_model_block(className, projectDirectory='.', dryrun=None, force=None,):
+def create_model_block(className, projectDirectory='.', dryrun=None, force=None):
     """Generates a Model Block class.
 
     The file will be located in ``project_name/models/blocks/block_name.py``
